pub struct CreatePresignedNotebookUrlFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreatePresignedNotebookUrl.
Gets an authentication token and the URL at which the notebook can be accessed. During programmatic access, CreatePresignedNotebookUrl must be called every 10 minutes to refresh the authentication token. For information about granting programmatic access, see Grant programmatic access.
Implementations
Sourceimpl CreatePresignedNotebookUrlFluentBuilder
impl CreatePresignedNotebookUrlFluentBuilder
Sourcepub fn as_input(&self) -> &CreatePresignedNotebookUrlInputBuilder
pub fn as_input(&self) -> &CreatePresignedNotebookUrlInputBuilder
Access the CreatePresignedNotebookUrl as a reference.
Sourcepub async fn send(
self,
) -> Result<CreatePresignedNotebookUrlOutput, SdkError<CreatePresignedNotebookUrlError, HttpResponse>>
pub async fn send( self, ) -> Result<CreatePresignedNotebookUrlOutput, SdkError<CreatePresignedNotebookUrlError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreatePresignedNotebookUrlOutput, CreatePresignedNotebookUrlError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreatePresignedNotebookUrlOutput, CreatePresignedNotebookUrlError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.