CreatePresignedNotebookUrlOutputBuilder

Struct CreatePresignedNotebookUrlOutputBuilder 

#[non_exhaustive]
pub struct CreatePresignedNotebookUrlOutputBuilder { /* private fields */ }
Implementations

Source

impl CreatePresignedNotebookUrlOutputBuilder

pub fn notebook_url(self, input: impl Into<String>) -> Self

The URL of the notebook. The URL includes the authentication token and notebook file name and points directly to the opened notebook.

This field is required.
pub fn set_notebook_url(self, input: Option<String>) -> Self

The URL of the notebook. The URL includes the authentication token and notebook file name and points directly to the opened notebook.

pub fn get_notebook_url(&self) -> &Option<String>

The URL of the notebook. The URL includes the authentication token and notebook file name and points directly to the opened notebook.

pub fn auth_token(self, input: impl Into<String>) -> Self

The authentication token for the notebook.

This field is required.
pub fn set_auth_token(self, input: Option<String>) -> Self

The authentication token for the notebook.

pub fn get_auth_token(&self) -> &Option<String>

The authentication token for the notebook.

pub fn auth_token_expiration_time(self, input: i64) -> Self

The UTC epoch time when the authentication token expires.

This field is required.
pub fn set_auth_token_expiration_time(self, input: Option<i64>) -> Self

The UTC epoch time when the authentication token expires.

pub fn get_auth_token_expiration_time(&self) -> &Option<i64>

The UTC epoch time when the authentication token expires.

pub fn build(self) -> Result<CreatePresignedNotebookUrlOutput, BuildError>

Consumes the builder and constructs a CreatePresignedNotebookUrlOutput. This method will fail if any of the following fields are not set: